<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Support\Facades\Hash;

class Booking extends Model
{
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable=[
        'name',
        'phone',
        'status',
        'comments',
        'appointment_date',
        'appointment_day',
        'appointment_time',
        'agent_id',
        'clinic_id',
        'location_id',
        'patient_type_id',
        'price',
        'new_price',
        'paid_price',
        'attendance',
        'discount_added',
        'patient_id',
        'attendance_status_id',
        'slot_number',
        'attendance_at',
        'view_to_doctor_at',
        'finish_at_doctor',
        'secondary_phone',
    ];
    /**
     * Boot Function.
     *
     * @todo Need To Make Observer.
     *
     * @return void
     */
    public static function boot()
    {
        parent::boot();

        self::created(function ($booking) {
           //$booking->attendance_status_id=AttendanceStatus::where("mark_as_adefault",1)->first()?AttendanceStatus::where("mark_as_adefault",1)->first()->id:'';
           //$booking->save();
            //dd(request()->all());
            //dd();

            if(request()->filled('booking_before') && request()->booking_before==false){
                if(User::where('phone',$booking->phone)->first() == null && User::where('secondary_phone',$booking->phone)->first() == null){

                    $user=User::firstOrCreate(['phone'=>$booking->phone],['phone'=>$booking->phone,'secondary_phone'=>$booking->secondary_phone,'name'=>$booking->name,'type'=>'patient','occupation'=>request()->occupation,'location_id'=>$booking->location_id,'password'=>Hash::make('123456789')]);
                    $booking->patient_id=$user->id;
                    $booking->save();

                    if($booking->patient && $booking->patient->type=='user'){
                        $booking->patient->type='patient';
                        $booking->patient->save();
                    }
                }
            }else{

                    $booking->patient->type='patient';
                    $booking->patient->save();

                    $user = User::where('id',$booking->patient_id)->first();
                    $booking->name=$user->name;
                    $booking->phone=$user->phone;
                    $booking->secondary_phone=$user->secondary_phone;
                    $booking->save();

            }

        });
    }
    /************************************************************************/
    /****************************** Relations *******************************/
    /************************************************************************/
    /**
     * Location Relationship.
     *
     * @return BelongsTo
     **/

    public function location() : BelongsTo
    {
        return $this->belongsTo(Locations::class,'location_id','id');
    }
    /**
     * Agent Relationship.
     *
     * @return BelongsTo
     **/

    public function agent() : BelongsTo
    {
        return $this->belongsTo(User::class,'agent_id','id');
    }
    /**
     * Clinic Relationship.
     *
     * @return BelongsTo
     **/

    public function clinic() : BelongsTo
    {
        return $this->belongsTo(Clinic::class,'clinic_id','id');
    }
    /**
     * patientType Relationship.
     *
     * @return BelongsTo
     **/

    public function patientType() : BelongsTo
    {
        return $this->belongsTo(PatientType::class,'patient_type_id','id');
    }
    /**
     * patient Relationship.
     *
     * @return BelongsTo
     **/

    public function patient() : BelongsTo
    {
        return $this->belongsTo(User::class,'patient_id','id');
    }
    /**
     * AttendanceStatus Relationship.
     *
     * @return BelongsTo
     **/

    public function attendanceStatus() : BelongsTo
    {
        return $this->belongsTo(AttendanceStatus::class,'attendance_status_id','id');
    }

    public function getSlotNumberAttribute(){
        if($this->attributes['slot_number']==1000){
            return $this->attributes['slot_number']=0;
        }
        return $this->attributes['slot_number'];
    }

}
