<?php

namespace App\Datatables;
use App\Booking;
use App\Clinic;
use App\Operation;
use App\User;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Services\DataTable;

class OperationDataTables extends DataTable
{
    use BuilderParameters;

    /**
     * Build DataTable class.
     *
     * @param mixed $query Results from query() method.
     * @return \Yajra\DataTables\DataTableAbstract
     */
    public function dataTable($query)
    {
        return datatables()
            ->eloquent($query)
            ->editColumn('checkbox', $this->getColumnCheckboxHtml())
            ->editColumn("patient.name",function ($model){
                if($model->patient) {
                    return '<a href="#" onclick="quickViewEntity(' . $model->patient->id . ')" >' . $model->patient->name . '</a>';
                }
                return "N/A";
            })
            ->editColumn("patient.phone",function ($model){
                return $model->patient?$model->patient->phone:"N/A";

            })
            ->editColumn("patient.secondary_phone",function ($model){
                return $model->patient?$model->patient->secondary_phone:"N/A";

            })
            ->editColumn("operation_location.name",function ($model){
                return $model->operation_location?$model->operation_location->name_val:"N/A";

            })
            ->editColumn("operation_date",function ($model){
                return $model->operation_date." ".$model->operation_time;

            })
            ->editColumn('created_at',function ($model){
                return date("Y-m-d H:i:s",strtotime($model->created_at));
            })
            ->editColumn('actions',function($model){
                $view    = sprintf('<a href="%s" class="btn btn-sm btn-clean btn-icon btn-icon-md" title="%s"><i class="la la-eye"></i></a>',route(config('system.admin.name').'operations.show',[$model->id]), __('main.show'));
                $edit    = sprintf('<a href="%s" class="btn btn-sm btn-clean btn-icon btn-icon-md" title="%s"><i class="la la-edit"></i></a>',route(config('system.admin.name').'operations.edit',[$model->id]), __('main.edit'));
                $delete  = sprintf('<a data-id="'.$model->id.'" id="Delete_'.$model->id.'" class="OperationDelete btn btn-sm btn-clean btn-icon btn-icon-md"  title="%s"><i class="la la-trash"></i></a>',__('main.delete'));

                $delete.=sprintf('
                        <script defer>
                            $("#Delete_%s").on("click",(e)=>{
                                swal.fire({
                                    title: "%s",
                                    text: "%s",
                                    type: "warning",
                                    showCancelButton: true,
                                    confirmButtonText: "%s",
                                    cancelButtonText: "%s",
                                    reverseButtons: true
                                }).then(function(result){
                                    if (result.value) {
                                        axios.post("%s", {_method: "DELETE"}).then((res) => {
                                            if (res.data.success) {
                                                swal.fire("%s", "%s", "success");
                                                setTimeout(() => {
                                                    window.location = "%s";
                                                }, 1000)
                                            }
                                        }).catch(() => {
                                            window.location = "%s";
                                        });
                                    } else if (result.dismiss === "cancel") {
                                        swal.fire("%s", "%s", "error");
                                    }
                                });
                            })
                        </script>',
                    $model->id,
                    __('main.ask-delete'),
                    __('main.ask-delete') .$model->name,
                    __('main.yes'),
                    __('main.no'),
                    route(config('system.admin.name').'operations.destroy',[$model->id]),
                    __('main.success'),
                    __('main.deleted-message'),
                    route('admin.operations.index'),
                    route('admin.operations.index'),
                    __('main.canceled'),
                    __('main.no_data_deleted')

                );

                return $view . ' ' . $edit .' '.$delete;
            })
            ->rawColumns(['checkbox','patient.name','type','actions']);
    }

    /**
     * Get query source of dataTable.
     *
     * @param \App\Operation $model
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function query(Operation $model)
    {
        return $model->with(['patient','operation_location'])->newQuery();
    }

    /**
     * Optional method if you want to use html builder.
     *
     * @return \Yajra\DataTables\Html\Builder
     */
    public function html()
    {
        $this->order_column=5;
        return $this->builder()
            ->setTableId('Operations-table')
            ->columns($this->getColumns())
            ->minifiedAjax()
            ->buttons($this->getButtons())
            ->parameters($this->getCustomBuilderParameters([1,2,3,4,5], [], GetLanguage() == 'ar'));
    }

    /**
     * Get columns.
     *
     * @return array
     */
    protected function getColumns()
    {
        return [
            Column::computed('checkbox', $this->getTitleCheckboxHtml())->width(15)->printable(false),
            Column::make('patient.name', 'patient.name')->title(trans('main.name')),
            Column::make('patient.phone', 'patient.phone')->title(trans('main.phone')),
            Column::make('patient.secondary_phone', 'patient.secondary_phone')->title(trans('main.secondary_phone')),
            Column::make('operation_date', 'operation_date')->title(trans('main.day')),
            Column::make('operation_location.name', 'operation_location.name')->title(trans('main.operation_location')),
            Column::make('created_at', 'created_at')->title(trans('main.created_at')),
            Column::make('actions', 'actions')->title(trans('main.actions'))->searchable(false)->orderable(false)->printable(false),
        ];
    }

    /**
     * Get filename for export.
     *
     * @return string
     */
    protected function filename()
    {
        return 'Operations_' . date('YmdHis');
    }
}
