<?php

namespace App\Http\Controllers\Admin\Resource;

use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\ApplicationSettingsRequest;
use App\Repositories\Contract\ApplicationSettingRepository;

class ApplicationSettingsController extends Controller
{
    /**
     * @var ApplicationSettingRepository
     */
    private $repository;

    /**
     * View Path.
     *
     * @var string
     */
    private $viewPath = 'application_settings';


    /**
     * @param ApplicationSettingRepository $repository
     */
    public function __construct(ApplicationSettingRepository $repository)
    {
        $this->repository = $repository;
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function edit()
    {
        $edit = $this->repository->all()->pluck('data', 'key');
        if ($edit) {
            return view("backend.{$this->viewPath}.edit", [
                'title' => __('main.edit') . ' ' . __('main.application_settings'),
                'edit' => $edit,
            ]);
        }
    }

    /**
     * store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(ApplicationSettingsRequest $request)
    {
        $store = $this->repository->store($request->all());

        if (!$store) {
            return $this->apiResponse(__('main.faild_create'), true, 422);
        }
        return $this->apiResponse($store, true, 200);
    }
}
