<?php

namespace App\Http\Controllers\Admin\Resource;

use App\Datatables\BookingDataTables;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\BookingRequest;
use App\Repositories\Contract\BookingRepository;
use Illuminate\Http\Request;
use App\User;
Use \Carbon\Carbon;

class BookingController extends Controller
{
    /**
     * View Path.
     *
     * @var string
     */
    protected $viewPath = 'backend.bookings';

    /**
     * Resource Route.
     *
     * @var string
     */
    protected $resourceRoute = 'admin.bookings';

    /**
     * @param BookingRepository $repository
     */
    public function __construct(BookingRepository $repository)
    {
        $this->repository = $repository;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(BookingDataTables $dataTable)
    {
        return $dataTable->render("{$this->viewPath}.index", [
            'title' =>  __('main.bookings'),
        ]);
    }

    public function create()
    {
        return view("{$this->viewPath}.create", [
            'title' => __('main.add')  . ' ' . __('main.booking'),
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return Response
     */
    public function store(BookingRequest $request)
    {
        $data = $request->all();


        /*if($data["booking_before"] == false){

            return App\Users::first();
        }*/
        //return $this->repository->all();

        if($data["booking_before"] == true){
            $appsOnFuture = $this->repository->instance()->where('patient_id',$data["patient_id"])->whereDate('appointment_date', '>=', Carbon::now())->get();
            if($appsOnFuture == null || count($appsOnFuture) == 0){
                return $this->bookNow($data);
            }else{
                return $this->apiResponse(__('main.have_future_appointments'), false, 422);
            }
        }else{
            return $this->bookNow($data);
        }

        /*if(User::where('phone',$data["phone"])->first() == null){
            $store = $this->repository->create($data);

            if (!$store) {
                return $this->apiResponse(__('main.faild_create'), true, 422);
            }
            return $this->apiResponse($store, true, 200);
        }else{
            return $this->apiResponse(__('main.client_already_exist'), false, 422);
        }*/
    }

    public function bookNow($data){

        if(
            $data["booking_before"] == true ||
            (User::where('phone',$data["phone"])->first() == null &&
            ($data["secondary_phone"] == null || User::where('phone',$data["secondary_phone"])->first() == null) &&
            User::where('secondary_phone',$data["phone"])->first() == null &&
            ($data["secondary_phone"] == null || User::where('secondary_phone',$data["secondary_phone"])->first() == null))
            ){
            $store = $this->repository->create($data);

            if (!$store) {
                return $this->apiResponse(__('main.faild_create'), true, 422);
            }
            return $this->apiResponse($store, true, 200);
        }else{
            return $this->apiResponse(__('main.client_already_exist'), false, 422);
        }
    }
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $show = $this->repository->find($id);
        if ($show) {
            return view("{$this->viewPath}.show", [
                'title' => __('main.show') . ' ' . __('main.booking').' : ' . $show->name,
                'show' => $show,
            ]);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        $object = $this->repository->find($id);
        if ($object) {
            return view("{$this->viewPath}.edit", [
                'title' => __('main.edit') . ' ' . ' ' . __('main.booking').' : ' . $object->name,
                'edit' => $object,
            ]);
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(BookingRequest $request, $id)
    {
        $data=$request->all();

        $update = $this->repository->update($id,$data);

        if (!$update) {
            return $this->apiResponse(__('main.faild_update'), true, 422);
        }

        return $this->apiResponse($update, true, 200);
    }
}
