<?php

namespace App\Http\Controllers\Admin\Resource;

use App\Datatables\EnableDateDataTables;
use App\Events\SendNotificationEvent;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\EnableDateRequest;
use App\Repositories\Contract\EnableAppointmentRepository;
use Illuminate\Http\Request;

class EnableDateController extends Controller
{
    /**
     * View Path.
     *
     * @var string
     */
    protected $viewPath = 'backend.enable_appointments';

    /**
     * Resource Route.
     *
     * @var string
     */
    protected $resourceRoute = 'admin.enabled_date';

    /**
     * @param EnableAppointmentRepository $repository
     */
    public function __construct(EnableAppointmentRepository $repository)
    {
        $this->repository = $repository;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(EnableDateDataTables $dataTable)
    {
        return $dataTable->render("{$this->viewPath}.index", [
            'title' =>  __('main.enabled_dates'),
        ]);
    }

    public function create()
    {
        return view("{$this->viewPath}.create", [
            'title' => __('main.add')  . ' ' . __('main.enabled_date'),
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return Response
     */
    public function store(EnableDateRequest $request)
    {
        $data = $request->all();

        $store = $this->repository->create($data);
        $event_data=[];
        $event_data['to']="booking_date";
        $event_data['booking_date']=$request->enabled_date;
        $event_data['title']="Dr.Ahmed Marzouk Clinic";
        $event_data['description']="this is a reminder that you can now book your slot on Dr.Ahmed Marzouk mobile app";
        event(new SendNotificationEvent($event_data));
        if (!$store) {
            return $this->apiResponse(__('main.faild_create'), true, 422);
        }
        return $this->apiResponse($store, true, 200);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $show = $this->repository->find($id);
        if ($show) {
            return view("{$this->viewPath}.show", [
                'title' => __('main.show') . ' ' . __('main.enabled_date').' : ' . $show->enable_date,
                'show' => $show,
            ]);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        $object = $this->repository->find($id);
        if ($object) {
            return view("{$this->viewPath}.edit", [
                'title' => __('main.edit') . ' ' . ' ' . __('main.enabled_date').' : ' . $object->enable_date,
                'edit' => $object,
            ]);
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(EnableDateRequest $request, $id)
    {
        $data=$request->all();

        $update = $this->repository->update($id,$data);

        if (!$update) {
            return $this->apiResponse(__('main.faild_update'), true, 422);
        }

        return $this->apiResponse($update, true, 200);
    }
}
