<?php

namespace App\Http\Controllers\Admin\Resource;

use App\Datatables\PatientDataTables;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\PatientRequest;
use App\Repositories\Contract\BookingRepository;
use App\Repositories\Contract\PatientRepository;
use Illuminate\Http\Request;
use App\User;

class PatientController extends Controller
{
    /**
     * View Path.
     *
     * @var string
     */
    protected $viewPath = 'backend.patients';

    /**
     * Resource Route.
     *
     * @var string
     */
    protected $resourceRoute = 'admin.patients';

    /**
     * @param PatientRepository $repository
     */
    public function __construct(PatientRepository $repository,BookingRepository $bookingRepository)
    {
        $this->repository = $repository;
        $this->bookingRepository=$bookingRepository;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(PatientDataTables $dataTable)
    {
        return $dataTable->render("{$this->viewPath}.index", [
            'title' =>  __('main.patients'),
        ]);
    }

    public function create()
    {
        return view("{$this->viewPath}.create", [
            'title' => __('main.add')  . ' ' . __('main.patient'),
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return Response
     */
    public function store(PatientRequest $request)
    {
        $data=$request->all();

        if(
            (User::where('phone',$data["phone"])->first() == null &&
            ($data["secondary_phone"] == null || User::where('phone',$data["secondary_phone"])->first() == null) &&
            User::where('secondary_phone',$data["phone"])->first() == null &&
            ($data["secondary_phone"] == null || User::where('secondary_phone',$data["secondary_phone"])->first() == null))
            ){
                $store = $this->repository->create($request->except(['clinic_id','patient_type_id','attendance','price','new_price','discount_added','booking_id']));

                $data['patient_id']=$store->id;

                if($data['booking_id'] != null) $this->bookingRepository->update($data['booking_id'],$data);
                if (!$store) {
                    return $this->apiResponse(__('main.faild_create'), true, 422);
                }
                return $this->apiResponse($store, true, 200);
            }else{
                return $this->apiResponse(__('main.client_already_exist'), true, 422);

            }


    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $show = $this->repository->find($id);
        if ($show) {
            return view("{$this->viewPath}.show", [
                'title' => __('main.show') . ' ' . __('main.patient').' : ' . $show->name,
                'show' => $show,
            ]);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        $object = $this->repository->find($id);
        if ($object) {
            return view("{$this->viewPath}.edit", [
                'title' => __('main.edit') . ' ' . ' ' . __('main.patient').' : ' . $object->name,
                'edit' => $object,
            ]);
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(PatientRequest $request, $id)
    {
        $data=$request->all();

        $update = $this->repository->update($id,$data);

        if (!$update) {
            return $this->apiResponse(__('main.faild_update'), true, 422);
        }

        return $this->apiResponse($update, true, 200);
    }
}
