<?php

namespace App\Http\Controllers\Admin\Resource;

use App\Datatables\ReceptionistDataTables;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\ReceptionistRequest;
use App\Repositories\Contract\ReceptionistRepository;
use Illuminate\Http\Request;

class ReceptionistController extends Controller
{
    /**
     * View Path.
     *
     * @var string
     */
    protected $viewPath = 'backend.receptionists';

    /**
     * Resource Route.
     *
     * @var string
     */
    protected $resourceRoute = 'admin.receptionists';

    /**
     * @param ReceptionistRepository $repository
     */
    public function __construct(ReceptionistRepository $repository)
    {
        $this->repository = $repository;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(ReceptionistDataTables $dataTable)
    {
        return $dataTable->render("{$this->viewPath}.index", [
            'title' =>  __('main.receptionists'),
        ]);
    }

    public function create()
    {
        return view("{$this->viewPath}.create", [
            'title' => __('main.add')  . ' ' . __('main.receptionist'),
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return Response
     */
    public function store(ReceptionistRequest $request)
    {
        $data = $request->all();

        $store = $this->repository->create($data);
        if (!$store) {
            return $this->apiResponse(__('main.faild_create'), true, 422);
        }
        return $this->apiResponse($store, true, 200);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $show = $this->repository->instance()->where('type','receptionist')->find($id);
        if ($show) {
            return view("{$this->viewPath}.show", [
                'title' => __('main.show') . ' ' . __('main.receptionist').' : ' . $show->name,
                'show' => $show,
            ]);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        $object = $this->repository->instance()->where('type','receptionist')->find($id);
        if ($object) {
            return view("{$this->viewPath}.edit", [
                'title' => __('main.edit') . ' ' . ' ' . __('main.receptionist').' : ' . $object->name,
                'edit' => $object,
            ]);
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(ReceptionistRequest $request, $id)
    {
        $data=$request->all();

        $update = $this->repository->update($id,$data);

        if (!$update) {
            return $this->apiResponse(__('main.faild_update'), true, 422);
        }

        return $this->apiResponse($update, true, 200);
    }
}
