<?php

namespace App\Http\Requests\Api;

use App\Child;
use Illuminate\Foundation\Http\FormRequest;

class UpdateKicksRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'child_id'=>'required|exists:children,id',
            'kicks'=>'required|numeric|gte:0',
        ];
    }
    /**
     * Get custom attributes for validator errors.
     *
     * @return array
     */
    public function attributes()
    {
        return[
            'child_id'=>__('main.child'),
            'kicks'=>__('main.kicks'),
        ];
    }
    /**
     * Get the validator instance for the request and
     * add attach callbacks to be run after validation
     * is completed.
     *
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function getValidatorInstance()
    {
        return parent::getValidatorInstance()->after(function($validator){
            // Call the after method of the FormRequest (see below)
            $this->after($validator);
        });
    }
    /**
     * Attach callbacks to be run after validation is completed.
     *
     * @param  \Illuminate\Contracts\Validation\Validator $validator
     * @return callback
     */
    public function after($validator)
    {
        if (!$this->verifyUserChild()) {
            $validator->errors()->add("children_not_belongs_to_parent", trans('main.children_not_belongs_to_parent'));
        }
    }
    /*
     * To Get Nursery Account Number Of Parent
     * @return Boolean
     */
    public function verifyUserChild() {
        $child=Child::find(request()->child_id);
        return $child?$child->parent_id==auth()->user()->id:false;
    }
}
