<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Facades\Auth;

class UserRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        $rules = [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users,email'],
            'phone' => ['required', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
            'user_image' => ['sometimes', 'nullable', 'image'],
        ];
        if (Auth::user()) {
            $rules['email'] = 'required|unique:users,email,' . Auth::user()->id . ',id';
            $rules['phone'] = 'required|unique:users,phone,' . Auth::user()->id . ',id';
            $rules['password'] = 'sometimes|nullable|min:8|confirmed';
        }
        return $rules;
    }

    public function attributes()
    {
        return [
            'name' => trans('main.name'),
            'email' => trans('main.email'),
            'phone' => trans('main.phone'),
            'secondary_phone' => trans('main.secondary_phone'),
            'password' => trans('main.password'),
            'image' => trans('main.image'),
        ];
    }
}
